<?php
$page_title = "iWallet Card 発行申請";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href="/ja/menu"><img src="../img/logo.png" alt="iWallet"></a></h1>
<?php include_once('template/base_sidebar.php'); ?>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>

						<p class="mb20 pleft40">以下の内容を確認して、よろしければ申請して下さい。</p>
						<div class="mb20 pleft40"><?php $this -> echoMessage(); ?></div>
						<form id="acForm" action="" method="post" class="pleft40 pb40">
							<table class="table col bdr default withdrawT odd calign w60p fontM ma90sp mb20">
								<tr>
									<th class="w40p">カードお申込枚数</th>
									<td class="w60p l"><?php $this -> echoIndex(); ?>枚</td>
								</tr>
								<tr>
									<th class="w40p">プリペイドカード種別</th>
									<td class="w60p l">チャージ上限<?php $this -> dispCardLimit(); ?></td>
								</tr>
								<tr>
									<th class="w40p">郵送先宛名</th>
									<td class="w60p l"><?php $this -> echoSippingName(); ?></td>
								</tr>
								<tr>
									<th class="w40p">郵送先国名</th>
									<td class="w60p l"><?php $this -> dispCountry(); ?></td>
								</tr>
								<tr>
									<th class="w40p">郵送先県名</th>
									<td class="w60p l"><?php $this -> echoState(VAL_INT_2); ?></td>
								</tr>
								<tr>
									<th class="w40p">郵送先市区町村</th>
									<td class="w60p l"><?php $this -> echoCity(VAL_INT_2); ?></td>
								</tr>
								<tr>
									<th class="w40p">郵送先ご住所</th>
									<td class="w60p l"><?php $this -> echoAddress(VAL_INT_2); ?></td>
								</tr>
								<tr>
									<th class="w40p">郵便番号</th>
									<td class="w60p l"><?php $this -> echoZipCode(VAL_INT_2); ?></td>
								</tr>
								<tr>
									<th class="w40p">電話番号</th>
									<td class="w60p l"><?php $this -> echoTel(VAL_INT_2); ?></td>
								</tr>
							</table>
							<p class="mb40 mt40 w60pButton">
								<a href="#" id="btnBackInput" class="btn bg-default">&laquo; 戻る</a>&emsp;
								<input type="button" id="btnComplete" value="iWallet Cardを申請する" class="btn bg-grad px240">
							</p>
							<input type="hidden" id="type" name="type" value="" />

							<input type="hidden" id="index" name="index" value="<?php $this -> echoIndex(); ?>" />
							<input type="hidden" id="sip_flg" name="sip_flg" value="<?php $this -> echoSipFlg(); ?>" />
							<input type="hidden" id="country" name="country" value="<?php $this -> echoCountry(); ?>" />
							<input type="hidden" id="state" name="state" value="<?php $this -> echoState(VAL_INT_1); ?>" />
							<input type="hidden" id="city" name="city" value="<?php $this -> echoCity(VAL_INT_1); ?>" />
							<input type="hidden" id="address" name="address" value="<?php $this -> echoAddress(VAL_INT_1); ?>" />
							<input type="hidden" id="zip_code" name="zip_code" value="<?php $this -> echoZipCode(VAL_INT_1); ?>" />
							<input type="hidden" id="tel" name="tel" value="<?php $this -> echoTel(VAL_INT_1); ?>" />
						</form>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/card_apply.js"></script>
</body>
</html>
